@@ -13,7 +13,7 @@ fn resolve_warm_jupyter(c: &mut Criterion<WallTime>) {
         .build()
         .unwrap();
 
-    let cache = &Cache::from_path(".cache").unwrap();
+    let cache = &Cache::from_path(".cache").unwrap().init().unwrap();
     let manifest = &Manifest::simple(vec![Requirement::from_pep508(
         pep508_rs::Requirement::from_str("jupyter").unwrap(),
     )
@@ -108,7 +108,7 @@ mod resolver {
             &index,
             &hashes,
             &build_context,
-            &installed_packages,
+            installed_packages,
             DistributionDatabase::new(client, &build_context, concurrency.downloads),
         )?;
 
