@@ -74,9 +74,11 @@ impl From<&ResolvedDist> for Requirement {
     fn from(resolved_dist: &ResolvedDist) -> Self {
         let source = match resolved_dist {
             ResolvedDist::Installable(dist) => match dist {
-                Dist::Built(BuiltDist::Registry(wheel)) => RequirementSource::Registry {
+                Dist::Built(BuiltDist::Registry(wheels)) => RequirementSource::Registry {
                     specifier: pep440_rs::VersionSpecifiers::from(
-                        pep440_rs::VersionSpecifier::equals_version(wheel.filename.version.clone()),
+                        pep440_rs::VersionSpecifier::equals_version(
+                            wheels.best_wheel().filename.version.clone(),
+                        ),
                     ),
                     index: None,
                 },
@@ -86,7 +88,7 @@ impl From<&ResolvedDist> for Requirement {
                     RequirementSource::Url {
                         url: wheel.url.clone(),
                         location,
-                        subdirectory: wheel.subdirectory.clone(),
+                        subdirectory: None,
                     }
                 }
                 Dist::Built(BuiltDist::Path(wheel)) => RequirementSource::Path {
@@ -96,7 +98,7 @@ impl From<&ResolvedDist> for Requirement {
                 },
                 Dist::Source(SourceDist::Registry(sdist)) => RequirementSource::Registry {
                     specifier: pep440_rs::VersionSpecifiers::from(
-                        pep440_rs::VersionSpecifier::equals_version(sdist.filename.version.clone()),
+                        pep440_rs::VersionSpecifier::equals_version(sdist.version.clone()),
                     ),
                     index: None,
                 },
