@@ -112,12 +112,12 @@ mod tests {
     #[test]
     #[cfg_attr(not(windows), ignore)]
     fn no_such_python_path() {
-        let result =
-            find_requested_python(r"C:\does\not\exists\python3.12", &Cache::temp().unwrap())
-                .unwrap()
-                .ok_or(Error::RequestedPythonNotFound(
-                    r"C:\does\not\exists\python3.12".to_string(),
-                ));
+        let cache = Cache::temp().unwrap().init().unwrap();
+        let result = find_requested_python(r"C:\does\not\exists\python3.12", &cache)
+            .unwrap()
+            .ok_or(Error::RequestedPythonNotFound(
+                r"C:\does\not\exists\python3.12".to_string(),
+            ));
         assert_snapshot!(
             format_err(result),
             @"Failed to locate Python interpreter at: `C:\\does\\not\\exists\\python3.12`"
