@@ -2,6 +2,7 @@ use std::future::Future;
 use std::path::{Path, PathBuf};
 
 use anyhow::Result;
+use url::Url;
 
 use distribution_types::{IndexLocations, InstalledDist, Requirement, Resolution, SourceDist};
 use pep508_rs::PackageName;
@@ -128,12 +129,14 @@ pub trait SourceBuildTrait {
 }
 
 /// A wrapper for [`uv_installer::SitePackages`]
-pub trait InstalledPackagesProvider {
+pub trait InstalledPackagesProvider: Clone + Send + Sync + 'static {
     fn iter(&self) -> impl Iterator<Item = &InstalledDist>;
     fn get_packages(&self, name: &PackageName) -> Vec<&InstalledDist>;
+    fn get_editables(&self, url: &Url) -> Vec<&InstalledDist>;
 }
 
 /// An [`InstalledPackagesProvider`] with no packages in it.
+#[derive(Clone)]
 pub struct EmptyInstalledPackages;
 
 impl InstalledPackagesProvider for EmptyInstalledPackages {
@@ -144,4 +147,8 @@ impl InstalledPackagesProvider for EmptyInstalledPackages {
     fn iter(&self) -> impl Iterator<Item = &InstalledDist> {
         std::iter::empty()
     }
+
+    fn get_editables(&self, _url: &Url) -> Vec<&InstalledDist> {
+        Vec::new()
+    }
 }
