@@ -33,7 +33,7 @@ pub(crate) struct Cli {
     pub(crate) cache_args: CacheArgs,
 
     /// The path to a `uv.toml` file to use for configuration.
-    #[arg(long, env = "UV_CONFIG_FILE", hide = true)]
+    #[arg(long, env = "UV_CONFIG_FILE")]
     pub(crate) config_file: Option<PathBuf>,
 }
 
@@ -1337,7 +1337,7 @@ pub(crate) struct PipInstallArgs {
     #[arg(long)]
     pub(crate) dry_run: bool,
 
-    #[arg(long, hide = true)]
+    #[arg(long, hide = true, group = "sources")]
     pub(crate) unstable_uv_lock_file: Option<String>,
 
     #[command(flatten)]
