@@ -43,6 +43,7 @@ static GLOBAL: tikv_jemallocator::Jemalloc = tikv_jemallocator::Jemalloc;
 mod cli;
 mod commands;
 mod compat;
+mod editables;
 mod logging;
 mod printer;
 mod settings;
@@ -176,8 +177,13 @@ async fn run() -> Result<ExitStatus> {
 
             // Resolve the settings from the command-line arguments and workspace configuration.
             let args = PipCompileSettings::resolve(args, workspace);
+            rayon::ThreadPoolBuilder::new()
+                .num_threads(args.shared.concurrency.installs)
+                .build_global()
+                .expect("failed to initialize global rayon pool");
 
-            let cache = cache.with_refresh(args.refresh);
+            // Initialize the cache.
+            let cache = cache.init()?.with_refresh(args.refresh);
             let requirements = args
                 .src_file
                 .into_iter()
@@ -246,8 +252,13 @@ async fn run() -> Result<ExitStatus> {
 
             // Resolve the settings from the command-line arguments and workspace configuration.
             let args = PipSyncSettings::resolve(args, workspace);
+            rayon::ThreadPoolBuilder::new()
+                .num_threads(args.shared.concurrency.installs)
+                .build_global()
+                .expect("failed to initialize global rayon pool");
 
-            let cache = cache.with_refresh(args.refresh);
+            // Initialize the cache.
+            let cache = cache.init()?.with_refresh(args.refresh);
             let sources = args
                 .src_file
                 .into_iter()
@@ -288,10 +299,16 @@ async fn run() -> Result<ExitStatus> {
             command: PipCommand::Install(args),
         }) => {
             args.compat_args.validate()?;
+
             // Resolve the settings from the command-line arguments and workspace configuration.
             let args = PipInstallSettings::resolve(args, workspace);
+            rayon::ThreadPoolBuilder::new()
+                .num_threads(args.shared.concurrency.installs)
+                .build_global()
+                .expect("failed to initialize global rayon pool");
 
-            let cache = cache.with_refresh(args.refresh);
+            // Initialize the cache.
+            let cache = cache.init()?.with_refresh(args.refresh);
             let requirements = args
                 .package
                 .into_iter()
@@ -360,6 +377,9 @@ async fn run() -> Result<ExitStatus> {
             // Resolve the settings from the command-line arguments and workspace configuration.
             let args = PipUninstallSettings::resolve(args, workspace);
 
+            // Initialize the cache.
+            let cache = cache.init()?;
+
             let sources = args
                 .package
                 .into_iter()
@@ -391,6 +411,9 @@ async fn run() -> Result<ExitStatus> {
             // Resolve the settings from the command-line arguments and workspace configuration.
             let args = PipFreezeSettings::resolve(args, workspace);
 
+            // Initialize the cache.
+            let cache = cache.init()?;
+
             commands::pip_freeze(
                 args.exclude_editable,
                 args.shared.strict,
@@ -408,6 +431,9 @@ async fn run() -> Result<ExitStatus> {
             // Resolve the settings from the command-line arguments and workspace configuration.
             let args = PipListSettings::resolve(args, workspace);
 
+            // Initialize the cache.
+            let cache = cache.init()?;
+
             commands::pip_list(
                 args.editable,
                 args.exclude_editable,
@@ -426,6 +452,9 @@ async fn run() -> Result<ExitStatus> {
             // Resolve the settings from the command-line arguments and workspace configuration.
             let args = PipShowSettings::resolve(args, workspace);
 
+            // Initialize the cache.
+            let cache = cache.init()?;
+
             commands::pip_show(
                 args.package,
                 args.shared.strict,
@@ -441,6 +470,9 @@ async fn run() -> Result<ExitStatus> {
             // Resolve the settings from the command-line arguments and workspace configuration.
             let args = PipCheckSettings::resolve(args, workspace);
 
+            // Initialize the cache.
+            let cache = cache.init()?;
+
             commands::pip_check(
                 args.shared.python.as_deref(),
                 args.shared.system,
@@ -467,6 +499,9 @@ async fn run() -> Result<ExitStatus> {
             // Resolve the settings from the command-line arguments and workspace configuration.
             let args = settings::VenvSettings::resolve(args, workspace);
 
+            // Initialize the cache.
+            let cache = cache.init()?;
+
             // Since we use ".venv" as the default name, we use "." as the default prompt.
             let prompt = args.prompt.or_else(|| {
                 if args.name == PathBuf::from(".venv") {
@@ -499,6 +534,9 @@ async fn run() -> Result<ExitStatus> {
             // Resolve the settings from the command-line arguments and workspace configuration.
             let args = settings::RunSettings::resolve(args, workspace);
 
+            // Initialize the cache.
+            let cache = cache.init()?;
+
             let requirements = args
                 .with
                 .into_iter()
@@ -535,12 +573,18 @@ async fn run() -> Result<ExitStatus> {
             // Resolve the settings from the command-line arguments and workspace configuration.
             let _args = settings::SyncSettings::resolve(args, workspace);
 
+            // Initialize the cache.
+            let cache = cache.init()?;
+
             commands::sync(globals.preview, &cache, printer).await
         }
         Commands::Lock(args) => {
             // Resolve the settings from the command-line arguments and workspace configuration.
             let _args = settings::LockSettings::resolve(args, workspace);
 
+            // Initialize the cache.
+            let cache = cache.init()?;
+
             commands::lock(globals.preview, &cache, printer).await
         }
         #[cfg(feature = "self-update")]
